
use warnings;
use strict;

package Mozilla::Persona::Validate::IMAPTalk;
use base 'Mozilla::Persona::Validate';

use Log::Report    qw/persona/;
use Mail::IMAPTalk ();

=chapter NAME
Mozilla::Persona::Validate::IMAPTalk - validate the existence via IMAP

=chapter SYNOPSIS
  # add to the configation of $domain.json
  { ...
    "validate" : {
      "class" : "Mozilla::Persona::Validator::IMAPTalk",
      "server" : "imap.example.com"
    },
    ...
  }

=chapter DESCRIPTION
The validator object must ensure that the user/password combination
is valid.  In this implementation, being able to log-in to an IMAP4
server (by using M<IMAP::Talk>) is a prove of the user's authenticity.

=chapter METHODS

=section Constructors

=c_method new OPTIONS
=requires server SERVER
The server to contact.
=cut

sub init($)
{   my ($self, $args) = @_;
    $self->{MPVI_server} = $args->{server} or panic;
    $self;
}

#------------
=section Accessors
=method server
=cut

sub server() {shift->{MPVI_server}}

sub isValid($$)
{   my ($self, $user, $password) = @_;

    my $imap = Mail::IMAPTalk->new
      ( Server   => $self->server
      , Username => $user
      , Password => $password
      , Uid      => 1
      );

   $imap or return 0;
   $imap->logout;
   1;
}

1;
